<?php

$config['captcha_enable'] = false;

$config['captcha_config'] = [
    'img_path'    => './assets/uploads/captcha/',
    'img_url'     => '/assets/uploads/captcha/',
    'img_width'   => '105',
    'img_height'  => 43,
    'expiration'  => 300, //time to live
    'word_length' => 4,
    'pool'        => '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ',
    // White background and border, black text and red grid
    'colors'      => [
        'background' => [255, 255, 255],
        'border'     => [255, 255, 255],
        'text'       => [0, 0, 0],
        'grid'       => [0, 0, 0],
    ],
    //    'word'        => 'R-team develop',
    //    'font_path'   => './assets/fonts/verbblack-webfont.ttf',
    //    'font_size'   => 18,
    'img_id'      => 'img_captcha',
];
