<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

/**
 * Upgrade callme module to version 1.1.0
 *
 * @author CIEXT skeleton
 */
class callme_upgrade_0 extends Abstract_upgrade
{

    public function up()
    {
        $ci = & get_instance();
        $ci->load->library('emailmng/emailmng_installer')->install_emailmng();
        
        return '1.1.0';
    }
    
    public function down()
    {
        return '0';
    }

}
