<?php 

$lang['title'] = 'Просмотр запросов с сайта';

$lang['display_as'] = array(
    'name' => 'Имя',
    'text' => 'Сообщение',
    'phone' => 'Телефон',
    'email' => 'Email',
    'date_add' => 'Дата обращения',
    'worked_out' => 'Отработан'
);

$lang['config_title'] = $lang['title'] . '/Настройки';


$lang['msg_ok'] = 'Данные сохранены';
$lang['btn_save'] = 'Сохранить';

$lang['config_aliases'] = array(
    'email' => '<p><b>Email для отправки уведомления.</b></p>если пусто - уведомление не отправляется',
    'subject' => '<b>Тема уведомления</b>',
    'template' => '<p><b>Шаблон уведомления.</b></p>'
    . '<p>Переменные ниже заменяются на данные пользователя:</p> '
    . '<p>{in_name} - имя</p>'
    . '<p>{in_email} - E-mail</p>'
    . '<p>{in_phone} - телефон</p>'
    . '<p>{in_text} - текс</p>',
);